document.addEventListener('DOMContentLoaded', () => {
  const startBtn = document.getElementById('startBtn');
  const stopBtn = document.getElementById('stopBtn');
  const transcriptionOutput = document.getElementById('transcription');
  const summaryOutput = document.getElementById('summary');
  const themeToggle = document.querySelector('.theme-toggle');
  
  let recognition = null;
  let isRecording = false;

  // Theme handling
  const toggleTheme = () => {
    const isDark = document.body.getAttribute('data-theme') === 'dark';
    document.body.setAttribute('data-theme', isDark ? 'light' : 'dark');
    localStorage.setItem('theme', isDark ? 'light' : 'dark');
  };

  themeToggle.addEventListener('click', toggleTheme);

  // Set initial theme
  const savedTheme = localStorage.getItem('theme') || 'light';
  document.body.setAttribute('data-theme', savedTheme);

  // Speech recognition setup
  if ('webkitSpeechRecognition' in window) {
    recognition = new webkitSpeechRecognition();
    recognition.continuous = true;
    recognition.interimResults = true;

    recognition.onresult = (event) => {
      let finalTranscript = '';
      
      for (let i = event.resultIndex; i < event.results.length; i++) {
        const transcript = event.results[i][0].transcript;
        if (event.results[i].isFinal) {
          finalTranscript += transcript;
        }
      }

      if (finalTranscript) {
        transcriptionOutput.textContent = finalTranscript;
        generateSummary(finalTranscript);
      }
    };

    recognition.onerror = (event) => {
      console.error('Speech recognition error:', event.error);
      stopRecording();
    };
  }

  // Recording controls
  const startRecording = () => {
    if (!recognition) {
      alert('Speech recognition is not supported in your browser.');
      return;
    }

    recognition.start();
    isRecording = true;
    startBtn.disabled = true;
    stopBtn.disabled = false;
    startBtn.style.opacity = '0.6';
  };

  const stopRecording = () => {
    if (recognition) {
      recognition.stop();
    }
    isRecording = false;
    startBtn.disabled = false;
    stopBtn.disabled = true;
    startBtn.style.opacity = '1';
  };

  // Simple summarization function (basic implementation)
  const generateSummary = (text) => {
    // Split into sentences
    const sentences = text.match(/[^.!?]+[.!?]+/g) || [];
    
    // Basic summary: take first 2 sentences or 20% of total sentences
    const summaryLength = Math.max(2, Math.ceil(sentences.length * 0.2));
    const summary = sentences.slice(0, summaryLength).join(' ');
    
    summaryOutput.textContent = summary || 'Not enough content for summary';
  };

  startBtn.addEventListener('click', startRecording);
  stopBtn.addEventListener('click', stopRecording);
});
